@@ -11,7 +11,6 @@ import os
 import sys
 import types
 
-import pathlib
 import pytest
 
 from .django_compat import is_django_unittest  # noqa
@@ -38,6 +37,11 @@ from .fixtures import transactional_db  # noqa
 
 from .lazy_django import django_settings_is_configured, skip_if_no_django
 
+try:
+    import pathlib
+except ImportError:
+    import pathlib2 as pathlib
+
 
 SETTINGS_MODULE_ENV = 'DJANGO_SETTINGS_MODULE'
 CONFIGURATION_ENV = 'DJANGO_CONFIGURATION'
@@ -118,8 +122,14 @@ def _add_django_project_to_path(args):
     def is_django_project(path):
         return path.is_dir() and (path / 'manage.py').exists()
 
+    def arg_to_path(arg):
+        # Test classes or functions can be appended to paths separated by ::
+        arg = arg.split("::", 1)[0]
+        return pathlib.Path(arg)
+
     def find_django_path(args):
-        args = [pathlib.Path(x) for x in args if not str(x).startswith("-")]
+        args = map(str, args)
+        args = [arg_to_path(x) for x in args if not x.startswith("-")]
         args = [p for p in args if p.is_dir()]
 
         if not args:
@@ -135,7 +145,7 @@ def _add_django_project_to_path(args):
 
     project_dir = find_django_path(args)
     if project_dir:
-        sys.path.insert(0, str(project_dir))
+        sys.path.insert(0, str(project_dir.absolute()))
         return PROJECT_FOUND % project_dir
     return PROJECT_NOT_FOUND
 
